# CraftBeerPi4 Plugin to import Beer.XML and KBHv2 recipes

## Currently, the latest cbpi4 version from the GIT repo is required. Some changes in the ui are also required for better usability

## This plugin is still BETA


- Beer.xml file or kbh database needs to be uploaded from other webpage
	- You need to navifate to IP_OF_CBPI:PORT/cbpi_RecipeImport/static/index.html
- Please check also cbpi4 Settings as several parameters will be added by this plugin.
- The plugin is based on an actor and needs to be activasted in the hardware section under actors
- Once created, add the actor to your dashboard
- Recipe creation for uploaded xml file or kbh database recipes can be done by hitting the 3 dots next to the actor.
	- So called Actor actions are used for this feature
	- It is also recommended to install the cbpi4-BM_Steps plugin for full fucnionality

- Changelog:

** 24.03.21:

	- Initial release
